==> nextcloud-app-mail-1.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Aŭtomata rekono malsukcesis. Bv. uzi permanan reĝimon.",
    "Updating account failed: " : "Ĝisdatigo de konto malsukcesis:",
    "Embedded message %s" : "Enkorpiga mesaĝo %s",
    "Important" : "Grava",
    "Work" : "Laboro",
    "Personal" : "Persona",
    "Later" : "Poste",
    "Mails" : "Retpoŝtoj",
    "Mail" : "Retpoŝtilo",
    "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Password" : "Pasvorto",
    "Manual" : "Manlibro",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Connecting" : "Konektante",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Account settings" : "Kontaj agordoj",
    "Change name" : "Ŝanĝi nomon",
    "Signature" : "Subskribo",
    "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
    "Writing mode" : "Skribreĝimo",
    "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
    "Mail server" : "Retpoŝtoservilo",
    "Email address" : "Retpoŝtadreso",
    "Cancel" : "Nuligi",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
    "From" : "De",
    "Select account" : "Elekti konton",
    "To" : "Al",
    "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
    "No contacts found." : "Neniuj kontaktoj trovitaj.",
    "Subject" : "Temo",
    "Subject …" : "Temo …",
    "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
    "Write message …" : "Verku mesaĝon …",
    "Saving draft …" : "Konservado de malneto...",
    "Draft saved" : "Malneto konservita",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Enable formatting" : "Ebligi formatado",
    "Enter a date" : "Entajpu daton",
    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
    "Sending …" : "Sendado...",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Go back" : "Reveni",
    "Retry" : "Reprovi",
    "Message sent!" : "Mesaĝo sendiĝis!",
    "Send" : "Sendi",
    "Uploading {percent}% …" : "Alŝutas {percent} %…",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Plain text" : "Ebenaĵa teksto",
    "Draft: " : "Malneto:",
    "Unfavorite" : "Malpliŝatati",
    "Favorite" : "Pliŝatati",
    "Read" : "Legi",
    "Unselect" : "Malelekti",
    "Select" : "Elekti",
    "Edit tags" : "Redakti etikedojn",
    "Move" : "Movi",
    "More actions" : "Pliaj agoj",
    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
    "Report this bug" : "Raporti tiun problemon",
    "All day" : "Tuttage",
    "Create" : "Krei",
    "Could not create event" : "Ne eblis krei okazaĵon",
    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
    "Choose" : "Elekti",
    "Favorites" : "Pliŝataĵoj",
    "Other" : "Alia",
    "Reply" : "Respondi",
    "Reply to sender only" : "Respondi nur al sendinto",
    "Forward" : "Antaŭen",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Unnamed" : "Nenomita",
    "Embedded message" : "Enkorpiga mesaĝo",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "New message" : "Nova mesaĝo",
    "Settings" : "Agordoj",
    "Quota" : "Kvoto",
    "Saving" : "Konservado",
    "Move down" : "Movi malsupren",
    "Remove account" : "Forigi konton",
    "Loading …" : "Ŝargas …",
    "Mark all as read" : "Marki ĉion kiel legita",
    "Clear cache" : "Forviŝi la kaŝmemoron",
    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
    "No message selected" : "Neniu mesaĝo elektita",
    "Delete" : "Forigi",
    "Copy to clipboard" : "Kopii tondejen",
    "Add" : "Aldoni",
    "Disabled" : "Malŝaltita",
    "Enabled" : "Ŝaltita",
    "Custom" : "Propra",
    "Signature …" : "Subskribo …",
    "Save signature" : "Konservi subskribon",
    "Set" : "Uzi",
    "Unset" : "Malprotekti",
    "Tag already exists" : "La etikedo jam ekzistas",
    "Not found" : "Ne trovita",
    "Remove" : "Forigi",
    "Import into {calendar}" : "Importi en {calendar}",
    "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
    "Airplane" : "Aviadilo",
    "Reservation {id}" : "Rezervejo {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
    "Train" : "Trajno",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
    "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
    "Mail app" : "Retpoŝtprogrameto",
    "Reset" : "Restarigi",
    "Email: {email}" : "Retpoŝto: {email}",
    "General" : "Ĝenerala",
    "IMAP" : "IMAP",
    "User" : "Uzanto",
    "Host" : "Gastigo",
    "Port" : "Pordo",
    "SMTP" : "SMTP",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Search" : "Serĉi",
    "Refresh" : "Aktualigi",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "All" : "Ĉiuj",
    "Archive" : "Arĥivujo",
    "Drafts" : "Malnetujo",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Inbox" : "Ricevujo",
    "Junk" : "Trudmesaĝujo",
    "Sent" : "Senditujo",
    "Trash" : "Rubujo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargi {tag}{name}{endtag}",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraris ŝargi mesaĝon",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se vi ne volas viziti tiun paĝon, vi povas reiri al <a href=\"%s\">retpoŝtilo</a>.",
    "Continue to %s" : "Daŭrigi al %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-2.2.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Enkorpiga mesaĝo %s",
    "Important" : "Grava",
    "Work" : "Laboro",
    "Personal" : "Persona",
    "Later" : "Poste",
    "Mails" : "Retpoŝtoj",
    "Mail" : "Retpoŝtilo",
    "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Password" : "Pasvorto",
    "Manual" : "Manlibro",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Connecting" : "Konektante",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Account settings" : "Kontaj agordoj",
    "Change name" : "Ŝanĝi nomon",
    "Signature" : "Subskribo",
    "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
    "Writing mode" : "Skribreĝimo",
    "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
    "Mail server" : "Retpoŝtoservilo",
    "Email address" : "Retpoŝtadreso",
    "Cancel" : "Nuligi",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
    "From" : "De",
    "Select account" : "Elekti konton",
    "To" : "Al",
    "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
    "No contacts found." : "Neniuj kontaktoj trovitaj.",
    "Subject" : "Temo",
    "Subject …" : "Temo …",
    "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
    "Write message …" : "Verku mesaĝon …",
    "Saving draft …" : "Konservado de malneto...",
    "Draft saved" : "Malneto konservita",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Enable formatting" : "Ebligi formatado",
    "Enter a date" : "Entajpu daton",
    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
    "Sending …" : "Sendado...",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Go back" : "Reveni",
    "Retry" : "Reprovi",
    "Message sent!" : "Mesaĝo sendiĝis!",
    "Send" : "Sendi",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Plain text" : "Ebenaĵa teksto",
    "Draft: " : "Malneto:",
    "Unfavorite" : "Malpliŝatati",
    "Favorite" : "Pliŝatati",
    "Read" : "Legi",
    "Unselect" : "Malelekti",
    "Select" : "Elekti",
    "Edit tags" : "Redakti etikedojn",
    "Move" : "Movi",
    "More actions" : "Pliaj agoj",
    "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
    "Forward" : "Antaŭen",
    "Report this bug" : "Raporti tiun problemon",
    "All day" : "Tuttage",
    "Create" : "Krei",
    "Could not create event" : "Ne eblis krei okazaĵon",
    "Comment" : "Komento",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
    "Choose" : "Elekti",
    "Other" : "Alia",
    "Reply" : "Respondi",
    "Reply to sender only" : "Respondi nur al sendinto",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Unnamed" : "Nenomita",
    "Embedded message" : "Enkorpiga mesaĝo",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "Quota" : "Kvoto",
    "Saving" : "Konservado",
    "Move down" : "Movi malsupren",
    "Remove account" : "Forigi konton",
    "Loading …" : "Ŝargas …",
    "Mark all as read" : "Marki ĉion kiel legita",
    "Clear cache" : "Forviŝi la kaŝmemoron",
    "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
    "New message" : "Nova mesaĝo",
    "No message selected" : "Neniu mesaĝo elektita",
    "Message" : "Mesaĝo",
    "Delete" : "Forigi",
    "Copy to clipboard" : "Kopii tondejen",
    "Add" : "Aldoni",
    "Tags" : "Etikedoj",
    "Select tags" : "Elekti etikedojn",
    "Clear" : "Viŝi",
    "Search" : "Serĉi",
    "Date" : "Date",
    "Disabled" : "Malŝaltita",
    "Enabled" : "Ŝaltita",
    "Custom" : "Propra",
    "Signature …" : "Subskribo …",
    "Save signature" : "Konservi subskribon",
    "Set" : "Uzi",
    "Unset" : "Malprotekti",
    "Tag already exists" : "La etikedo jam ekzistas",
    "Not found" : "Ne trovita",
    "Remove" : "Forigi",
    "Untitled event" : "Sentitola okazaĵo",
    "Import into {calendar}" : "Importi en {calendar}",
    "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
    "Airplane" : "Aviadilo",
    "Reservation {id}" : "Rezervejo {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
    "Train" : "Trajno",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
    "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
    "Mail app" : "Retpoŝtprogrameto",
    "Reset" : "Restarigi",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "Email: {email}" : "Retpoŝto: {email}",
    "General" : "Ĝenerala",
    "IMAP" : "IMAP",
    "User" : "Uzanto",
    "Host" : "Gastigo",
    "Port" : "Pordo",
    "SMTP" : "SMTP",
    "Account connected" : "Konto konektita",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Refresh" : "Aktualigi",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "All" : "Ĉiuj",
    "Archive" : "Arĥivujo",
    "Drafts" : "Malnetujo",
    "Favorites" : "Pliŝataĵoj",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Inbox" : "Ricevujo",
    "Junk" : "Trudmesaĝujo",
    "Sent" : "Senditujo",
    "Trash" : "Rubujo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargi {tag}{name}{endtag}",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraris ŝargi mesaĝon",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "Continue to %s" : "Daŭrigi al %s"
},
"nplurals=2; plural=(n != 1);");
